@@ -1,5 +1,5 @@
 import fnmatch
-import platform
+import distro
 import pwd
 import subprocess
 import shlex
@@ -98,7 +98,7 @@ def apt_install():
     """ Execute the install from all apt_files found in the repos folder, but first
     updates the apt cache
     """
-    _, _, dist_name = platform.linux_distribution()
+    _, _, dist_name = distro.linux_distribution()
     apt_files = search_apt_requirements('/home/odoo/instance')
     apt_files.append('/tmp/apt_dependencies.txt')
     download_files([
